@@ -8,11 +8,8 @@ package Group::Git::Repo;
 
 use Moose;
 use version;
-use Carp;
-use Data::Dumper qw/Dumper/;
-use English qw/ -no_match_vars /;
 
-our $VERSION = version->new('0.3.0');
+our $VERSION = version->new('0.3.1');
 
 extends 'Group::Git';
 
@@ -35,24 +32,29 @@ __END__
 
 =head1 NAME
 
-Group::Git::Repo - <One-line description of module's purpose>
+Group::Git::Repo - Git repository details object.
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Repo version 0.3.0.
+This documentation refers to Group::Git::Repo version 0.3.1.
 
 
 =head1 SYNOPSIS
 
    use Group::Git::Repo;
 
-   # Brief but working code example(s) here showing the most common usage(s)
-   # This section will be as far as many users bother reading, so make it as
-   # educational and exemplary as possible.
-
+   # create a new repository object
+   my $ggr = Group::Git::Repo->new(
+       name => 'some-repo',
+       url  => 'http://example.com/some-repo/',
+       git  => 'git@example.com/some-repo.git',
+   );
 
 =head1 DESCRIPTION
 
+C<Group::Git::Repo> stores the basic information about a git repository for
+other L<Group::Git> modules to use. It does nothing by it's self.
+
 =head1 SUBROUTINES/METHODS
 
 =head1 DIAGNOSTICS
